waveformtools.CoM — waveformtools 2022-05-03 documentation

# waveformtools.CoM

Centre of mass correction for the waveforms.

Functions

`X_com_moments`(time_axis, Xcom, order) | Compute the nth order temporal moment of the COM coordinates.
`boost_waveform`(unboosted_waveform, ...) | Boost the waveform given the unboosted waveform and the boost conformal factor.
`compute_com_alpha`(time_i, time_f, Xcom_0, Xcom_1) | Computes the CoM correction alpha parameter: the mean displacement of the system, of the COM correction as defined in Woodford et al. 2019 (Phys.
`compute_com_beta`(time_i, time_f, Xcom_0, Xcom_1) | Computes the CoM beta parameter: the mean drift of the system, of the COM correction as defined in Woodford et al. 2019 (Phys.
`compute_conformal_k`(vec_v, info[, spin_phase]) | Compute the conformal factor for the boost transformation
`compute_translation_alpha_modes`(time_axis, ...) | Compute the translation scalar \(\alpha\) in its spherical harmonic components given the mean motion of the centre of mass.

waveformtools.CoM.X_com_moments(time_axis, Xcom, order)

  Compute the nth order temporal moment of the COM coordinates.

  Parameters:
    time_axis: 1d array

      The time axis.

    Xcom: list

      A list of three 1d arrays, each a 1d array containing the time series of the x, y and z co-ordinates in that order.

    order: int

      The order of the moment.

  Returns:
    moments: list

      A list containing three real numbers, one each for the moment of x, y and z locations.

waveformtools.CoM.boost_waveform(unboosted_waveform, conformal_factor)

  Boost the waveform given the unboosted waveform and the boost conformal factor.

  Parameters:
    unboosted_waveform: spherical_array

      A class instance of spherical array.

    conformal_factor: 2d array

      The conformal factor for the Lorentz transformation. It may be a single floating point number or an array on a spherical grid. The array will be of dimensions [ntheta, nphi].

    gridinfo: class instance

      The class instance that contains the properties of the spherical grid.

  Returns:
    boosted_waveform: sp_array

      The class instance sp_array that contains the boosted waveform.

waveformtools.CoM.compute_com_alpha(time_i, time_f, Xcom_0, Xcom_1)

  Computes the CoM correction alpha parameter: the mean displacement of the system, of the COM correction as defined in Woodford et al. 2019 (Phys. Rev. D 100, 124010).

  Parameters:
    time_i: float

      initial time

    time_f: float

      final time

    Xcom_0: list

      A list containing the zeroth order moments of the COM.

    Xcom_1: list

      A list containing the first order moments of the COM.

  Returns:
    com_alpha: list

      The list containig the alpha parameter vector

waveformtools.CoM.compute_com_beta(time_i, time_f, Xcom_0, Xcom_1)

  Computes the CoM beta parameter: the mean drift of the system, of the COM correction as defined in Woodford et al. 2019 (Phys. Rev. D 100, 124010).

  Parameters:
    time_i: float

      initial time

    time_f: float

      final time

    Xcom_0: list

      A list containing the zeroth order moments of the COM.

    Xcom_1: list

      A list containing the first order moments of the COM.

  Returns:
    com_beta: list

      The list containig the alpha parameter vector

waveformtools.CoM.compute_conformal_k(vec_v, info, spin_phase=0)
  Compute the conformal factor for the boost transformation

    :math:`k = exp(-2i lambda) gamma^3 (1 - mathbf{v} cdot mathbf{r})^3

waveformtools.CoM.compute_translation_alpha_modes(time_axis, com_alpha, com_beta)

  Compute the translation scalar \(\alpha\) in its spherical harmonic components given the mean motion of the centre of mass. These are basically the quantities in Eq. (4-5d) in the reference Woodford et al. 2019.

  Parameters:
    time_axis: 1d array

      The 1D array containing the time axis of the simulation.

    alpha: 1d array

      The 1D array containing the mean co-ordinate displacement of the COM of the system.

    beta: 1d array

      The 1D array containing the mean co-ordinate velocity of the COM.

  Returns:
    alpha_modesmodes_array

      A waveforms.modes_array object containing the SH decomposition of the ‘Alpha’ supertranslation variable.